#######
# risCorpusToCsv.py
# description : turn a ris file into a gargantext csv corpus
# licence : AGPL + CECILL v3
# author : quentin lobbé - qlobbe@iscpif.fr
#######

import sys
import csv
import rispy 
from datetime import date

# python3 risCorpusToCsv.py corpus.ris

path = ""

try :
    path = sys.argv[1]
except :
    print ("! args error\n")
    sys.exit(0)

def normalizePath(path) :
	splited = path.split('/')
	name = (splited[-1]).split('.')[0]
	root = '/'.join(splited[:-1])
	return (root,name)

root,name = normalizePath(path)

newName = name + ".csv"
if root != "":
	newName = root + '/' + newName


output = open(newName, "w")
header = "title\tsource\tpublication_year\tpublication_month\tpublication_day\tabstract\tauthors\tweight\n"
output.write(header)

with open(path, 'r') as corpus :
	 
	docs = rispy.load(corpus)
	
	for doc in docs :

		keys = doc.keys()
		
		if 'secondary_title' in keys :
			source = doc['secondary_title']
		else :
			source = ""

		if 'abstract' in keys :
			abstract = doc['abstract']
		else :
			abstract = ""			

		title = doc['title']

		month = '1'
		day = '1'
		if doc.__contains__('date'):
			tmp = doc['date'].split("/")
			year = tmp[0]
			month = tmp[1]
			day = tmp[2]
		else:
			if doc.__contains__('year'):
				year = doc['year'].replace('/','').replace('.','')
			else:
				year = str(date.today().year)

		if doc.__contains__('authors'):
			authors = ';'.join(doc['authors'])
		else:
			authors = ""
		

		row = str(title) + "\t" + str(source) + "\t" + year + "\t" + month + "\t" + day + "\t" + abstract + "\t" + authors + "\t" + str(1) + "\n"
		
		output.write(row)